@@ -7,6 +7,7 @@ from ...utils.token import parse_token
 from .commit import commit
 from ...utils.env_keys import REPORT_ERROR_KEY
 from ...utils.http_client import LaunchableClient
+from ...utils.session import clean_session_files
 
 
 @click.command()
@@ -30,6 +31,8 @@ from ...utils.http_client import LaunchableClient
 def build(ctx, build_name, source):
     token, org, workspace = parse_token()
 
+    clean_session_files(days_ago=14)
+
     # This command accepts REPO_NAME=REPO_DIST and REPO_DIST
     repos = [s.split('=') if re.match(r'[^=]+=[^=]+', s) else (s, s)
              for s in source]
@@ -93,7 +96,6 @@ def build(ctx, build_name, source):
         client = LaunchableClient(token)
         res = client.request("post", path, data=json.dumps(
             payload).encode(), headers=headers)
-        print(res.status_code)
         res.raise_for_status()
 
     except Exception as e:
